**This helper is a stand alone module to help get you started consuming and processing Inbound Parse data.**

## Table of Contents

* [Quick Start for Local Testing with Sample Data](#quick_start_local_sample)
* [Quick Start for Local Testing with Real Data](#quick_start_local_real)
* [Deploy to Heroku](#heroku)
* [Code Walkthrough](#code_walkthrough)
* [Testing the Source Code](#testing)
* [Contributing](#contributing)

<a name="quick_start_local_sample"></a>
# Quick Start for Local Testing with Sample Data

```bash
git clone https://github.com/sendgrid/sendgrid-go.git
cd sendgrid-go
```

Run the Inbound Parse listener in your terminal:

```bash
cd helpers/inbound/
go run inbound.go
```

In another terminal, run the test data sender:

```bash
cd [path to sendgrid-go/helpers/inbound]
go run inbound.go ./sample_data/default_data.txt http://127.0.0.1:8000/inbound
```

More sample data can be found [here](https://github.com/sendgrid/sendgrid-go/tree/master/helpers/inbound/sample_data).

View the results in the first terminal.

<a name="quick_start_local_real"></a>
# Quick Start for Local Testing with Real Data

[Setup your MX records.](https://sendgrid.com/docs/Classroom/Basics/Inbound_Parse_Webhook/setting_up_the_inbound_parse_webhook.html#-Setup) Depending on your domain name host, you may need to wait up to 48 hours for the settings to propagate.

Run the Inbound Parse listener in your terminal:

```bash
git clone https://github.com/sendgrid/sendgrid-go.git
go run inbound.go
```

In another terminal, use [ngrok](https://ngrok.com/) to allow external access to your machine:
```bash
ngrok http 8000
```

Update your SendGrid Incoming Parse settings: [Settings Page](https://app.sendgrid.com/settings/parse) | [Docs](https://sendgrid.com/docs/Classroom/Basics/Inbound_Parse_Webhook/setting_up_the_inbound_parse_webhook.html#-Pointing-to-a-Hostname-and-URL)

- For the HOSTNAME field, use the domain that you changed the MX records (e.g. inbound.yourdomain.com)
- For the URL field, use the URL generated by ngrok + /inbound, e.g http://XXXXXXX.ngrok.io/inbound

Next, send an email to [anything]@inbound.yourdomain.com, then look at the terminal where you started the Inbound Parse listener.

<a name="heroku"></a>
# Deploy to Heroku

Get a [Heroku](https://www.heroku.com) account.

[![Deploy](https://www.herokucdn.com/deploy/button.svg)](https://heroku.com/deploy?template=https://github.com/sendgrid/sendgrid-go/tree/heroku-deployment)

[Setup your MX records.](https://sendgrid.com/docs/Classroom/Basics/Inbound_Parse_Webhook/setting_up_the_inbound_parse_webhook.html#-Setup) Depending on your domain name host, you may need to wait up to 48 hours for the settings to propagate.

Update your SendGrid Incoming Parse settings: [Settings Page](https://app.sendgrid.com/settings/parse) | [Docs](https://sendgrid.com/docs/Classroom/Basics/Inbound_Parse_Webhook/setting_up_the_inbound_parse_webhook.html#-Pointing-to-a-Hostname-and-URL)

- For the HOSTNAME field, use the domain that you changed the MX records (e.g. inbound.yourdomain.com)
- For the URL field, use the URL generated by Heroku + /inbound, e.g https://[name-of-your-app].herokuapp.com/inbound

Next, send an email to [anything]@inbound.yourdomain.com, then look at your Heroku logs: https://dashboard.heroku.com/apps/[name-of-your-app]/logs

While you are waiting for your MX records to propagate, you can test by using the test data sender:

```bash
git clone https://github.com/sendgrid/sendgrid-go.git
cd sendgrid-go
go build
./sendgrid-go ./helpers/inbound/sample_data/default_data.txt https://[name-of-your-app].herokuapp.com/inbound
```

To make changes: clone, modify and push the changes. [Heroku CLI](https://devcenter.heroku.com/articles/heroku-command-line) is required.

For example:
```bash
git clone [repo url]
git checkout heroku-deployment
heroku git:remote -a [name-of-your-app]
---make changes---
git add -A
git commit -m "updated configuration"
git push heroku heroku-deployment:master
```

<a name="code_walkthrough"></a>
# Code Walkthrough

## inbound.go

This module runs a net/http server, that by default (you can change those settings [here](https://github.com/sendgrid/sendgrid-go/blob/master/helpers/inbound/conf.json), listens for POSTs on http://localhost:8000. When the server receives the POST, it parses and prints the key/value data.

## conf.json

This file contains application environment variables (located in [conf.json](https://github.com/sendgrid/sendgrid-go/blob/master/helpers/inbound/conf.json)).

## inbound.go & /sample_data

This module, in conjunction with the sample data, is also used to send sample test data. It is useful for testing and development, particularly while you wait for your MX records to propagate.

<a name="testing"></a>
# Testing the Source Code

Tests are located in the `helpers/inbound` folder:

- [inbound_test.go](https://github.com/sendgrid/sendgrid-go/blob/master/helpers/inbound/inbound_test.go)

Learn about testing this code [here](https://github.com/sendgrid/sendgrid-go/blob/master/CONTRIBUTING.md#testing).

<a name="contributing"></a>
# Contributing

If you would like to contribute to this project, please see our [contributing guide](https://github.com/sendgrid/sendgrid-go/blob/master/CONTRIBUTING.md). Thanks!
